==> haskell-deepseq-generics-0.2.0.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deepseq-generics
version:              0.2.0.0
visibility:           public
id:                   deepseq-generics-0.2.0.0-8nNqsEqjLZX4u3G8aVefRp
key:                  deepseq-generics-0.2.0.0-8nNqsEqjLZX4u3G8aVefRp
license:              BSD-3-Clause
copyright:            2012, Herbert Valerio Riedel
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
homepage:             https://github.com/hvr/deepseq-generics
synopsis:             GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.

    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).

    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.

    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.

category:             Control
abi:                  f64da4da48acf812e9675093d2f4bc9e
exposed:              True
exposed-modules:      Control.DeepSeq.Generics
import-dirs:          /usr/lib/ghc-9.2.8/site-local/deepseq-generics-0.2.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/deepseq-generics-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deepseq-generics
hs-libraries:         HSdeepseq-generics-0.2.0.0-8nNqsEqjLZX4u3G8aVefRp
depends:              base-4.16.4.0 deepseq-1.4.6.1 ghc-prim-0.8.0
haddock-interfaces:
    /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock

haddock-html:         /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deepseq-generics-0.2.0.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deepseq-generics
version:              0.2.0.0
visibility:           public
id:                   deepseq-generics-0.2.0.0-2AvwRkGxGIIDSGaMSkb7Th
key:                  deepseq-generics-0.2.0.0-2AvwRkGxGIIDSGaMSkb7Th
license:              BSD-3-Clause
copyright:            2012, Herbert Valerio Riedel
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
homepage:             https://github.com/hvr/deepseq-generics
synopsis:             GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.

    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).

    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.

    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.

category:             Control
abi:                  cc97d965b280a2f2c47920160df82f72
exposed:              True
exposed-modules:      Control.DeepSeq.Generics
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deepseq-generics-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deepseq-generics-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deepseq-generics-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deepseq-generics
hs-libraries:         HSdeepseq-generics-0.2.0.0-2AvwRkGxGIIDSGaMSkb7Th
depends:              base-4.17.2.1 deepseq-1.4.8.0 ghc-prim-0.9.1
haddock-interfaces:
    /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock

haddock-html:         /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
